@@ -346,6 +346,8 @@ public class AccessibleImpl extends UnknownImpl implements AccessibleOperations
 			  role = Role.ROLE_VIEWPORT;
 		  else if (javaRole == AccessibleRole.WINDOW)
 			  role = Role.ROLE_WINDOW;
+		  else if (javaRole.toDisplayString (java.util.Locale.US).equalsIgnoreCase ("paragraph"))
+		          role = Role.ROLE_PARAGRAPH;
 		  else
 			  role = Role.ROLE_EXTENDED;
 	  }
@@ -396,7 +398,14 @@ public class AccessibleImpl extends UnknownImpl implements AccessibleOperations
 	  return "";
   }
 
-  public void unImplemented () {}
-  public void unImplemented2 () {}
-  public void unImplemented3 () {}
+  public String[] getAttributes () {
+      return new String[0];
+  }
+
+  public Application getApplication () {
+      // FIXME: need to return the real app object for this instance
+      return null;
+  }
+
+  public void unimplemented () {}
 }
